# -*- coding: utf-8 -*-

"""Tests dict input objects for `cookiecutter.prompt` module."""

import pytest
import yaml

from cookiecutter import prompt

FIXTURES = []


# @pytest.mark.parametrize("input_dicts,invalid", FIXTURES)
# def test_hook_checkbox(self, monkeypatch):
#     """Verify `prompt_for_config` call `read_user_variable` on dict request."""
#
